@@ -48,16 +48,17 @@ import java.util.Set;
 import org.apache.activemq.artemis.api.jms.ActiveMQJMSConstants;
 import org.apache.activemq.artemis.jms.client.ActiveMQConnectionForContext;
 import org.apache.activemq.artemis.jms.client.ActiveMQConnectionForContextImpl;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 /**
  * Implements the JMS Connection API and produces {@link ActiveMQRASession} objects.
  */
 public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForContextImpl implements ActiveMQRASessionFactory, ActiveMQConnectionForContext, Referenceable {
 
-   /**
-    * Trace enabled
-    */
-   private static boolean trace = ActiveMQRALogger.LOGGER.isTraceEnabled();
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
+
 
    /**
     * Are we closed?
@@ -120,6 +121,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    private final Set<TemporaryTopic> tempTopics = new HashSet<>();
 
+   private boolean allowLocalTransaction;
+
    /**
     * Constructor
     *
@@ -143,8 +146,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
 
       this.type = type;
 
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("constructor(" + mcf + ", " + cm + ", " + type);
+      if (logger.isTraceEnabled()) {
+         logger.trace("constructor({}, {}, {})", mcf, cm, type);
       }
    }
 
@@ -194,9 +197,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public void setReference(final Reference reference) {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("setReference(" + reference + ")");
-      }
+      logger.trace("setReference({})", reference);
 
       this.reference = reference;
    }
@@ -208,9 +209,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public Reference getReference() {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("getReference()");
-      }
+      logger.trace("getReference()");
 
       return reference;
    }
@@ -221,9 +220,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     * @param name The user name
     */
    public void setUserName(final String name) {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("setUserName(" + name + ")");
-      }
+      logger.trace("setUserName({})", name);
 
       userName = name;
    }
@@ -234,9 +231,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     * @param password The password
     */
    public void setPassword(final String password) {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("setPassword(****)");
-      }
+      logger.trace("setPassword(****)");
 
       this.password = password;
    }
@@ -249,9 +244,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public String getClientID() throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("getClientID()");
-      }
+      logger.trace("getClientID()");
 
       checkClosed();
 
@@ -270,9 +263,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public void setClientID(final String cID) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("setClientID(" + cID + ")");
-      }
+      logger.trace("setClientID({})", cID);
 
       throw new IllegalStateException(ISE);
    }
@@ -287,8 +278,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public QueueSession createQueueSession(final boolean transacted, final int acknowledgeMode) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createQueueSession(" + transacted + ", " + acknowledgeMode + ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createQueueSession({}, {})", transacted, acknowledgeMode);
       }
 
       checkClosed();
@@ -308,9 +299,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public XAQueueSession createXAQueueSession() throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createXAQueueSession()");
-      }
+      logger.trace("createXAQueueSession()");
 
       checkClosed();
 
@@ -337,15 +326,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
                                                       final String messageSelector,
                                                       final ServerSessionPool sessionPool,
                                                       final int maxMessages) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createConnectionConsumer(" + queue +
-                                          ", " +
-                                          messageSelector +
-                                          ", " +
-                                          sessionPool +
-                                          ", " +
-                                          maxMessages +
-                                          ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createConnectionConsumer({}, {}, {}, {})", queue, messageSelector, sessionPool, maxMessages);
       }
 
       throw new IllegalStateException(ISE);
@@ -361,8 +343,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public TopicSession createTopicSession(final boolean transacted, final int acknowledgeMode) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createTopicSession(" + transacted + ", " + acknowledgeMode + ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createTopicSession({}, {})", transacted, acknowledgeMode);
       }
 
       checkClosed();
@@ -382,9 +364,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public XATopicSession createXATopicSession() throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createXATopicSession()");
-      }
+      logger.trace("createXATopicSession()");
 
       checkClosed();
 
@@ -411,15 +391,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
                                                       final String messageSelector,
                                                       final ServerSessionPool sessionPool,
                                                       final int maxMessages) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createConnectionConsumer(" + topic +
-                                          ", " +
-                                          messageSelector +
-                                          ", " +
-                                          sessionPool +
-                                          ", " +
-                                          maxMessages +
-                                          ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createConnectionConsumer({}, {}, {}, {})", topic, messageSelector, sessionPool, maxMessages);
       }
 
       throw new IllegalStateException(ISE);
@@ -442,17 +415,9 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
                                                              final String messageSelector,
                                                              final ServerSessionPool sessionPool,
                                                              final int maxMessages) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createConnectionConsumer(" + topic +
-                                          ", " +
-                                          subscriptionName +
-                                          ", " +
-                                          messageSelector +
-                                          ", " +
-                                          sessionPool +
-                                          ", " +
-                                          maxMessages +
-                                          ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createConnectionConsumer({}, {}, {}, {}, {})",
+            topic, subscriptionName, messageSelector, sessionPool, maxMessages);
       }
 
       throw new IllegalStateException(ISE);
@@ -470,13 +435,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
    public ConnectionConsumer createConnectionConsumer(final Destination destination,
                                                       final ServerSessionPool pool,
                                                       final int maxMessages) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createConnectionConsumer(" + destination +
-                                          ", " +
-                                          pool +
-                                          ", " +
-                                          maxMessages +
-                                          ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createConnectionConsumer({}, {}, {})", destination, pool, maxMessages);
       }
 
       throw new IllegalStateException(ISE);
@@ -497,15 +457,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
                                                       final String name,
                                                       final ServerSessionPool pool,
                                                       final int maxMessages) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createConnectionConsumer(" + destination +
-                                          ", " +
-                                          name +
-                                          ", " +
-                                          pool +
-                                          ", " +
-                                          maxMessages +
-                                          ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createConnectionConsumer({}, {}, {}, {})", destination, name, pool, maxMessages);
       }
 
       throw new IllegalStateException(ISE);
@@ -521,8 +474,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public Session createSession(final boolean transacted, final int acknowledgeMode) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createSession(" + transacted + ", " + acknowledgeMode + ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createSession({}, {})", transacted, acknowledgeMode);
       }
 
       checkClosed();
@@ -537,9 +490,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public XASession createXASession() throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createXASession()");
-      }
+      logger.trace("createXASession()");
 
       checkClosed();
       return allocateConnection(type);
@@ -553,9 +504,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public ConnectionMetaData getMetaData() throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("getMetaData()");
-      }
+      logger.trace("getMetaData()");
 
       checkClosed();
       return mcf.getMetaData();
@@ -569,9 +518,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public ExceptionListener getExceptionListener() throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("getExceptionListener()");
-      }
+      logger.trace("getExceptionListener()");
 
       throw new IllegalStateException(ISE);
    }
@@ -584,9 +531,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public void setExceptionListener(final ExceptionListener listener) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("setExceptionListener(" + listener + ")");
-      }
+      logger.trace("setExceptionListener({})", listener);
 
       throw new IllegalStateException(ISE);
    }
@@ -600,9 +545,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
    public void start() throws JMSException {
       checkClosed();
 
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("start() " + this);
-      }
+      logger.trace("start() {}", this);
 
       synchronized (sessions) {
          if (started) {
@@ -623,9 +566,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public void stop() throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("stop() " + this);
-      }
+      logger.trace("stop() {}", this);
 
       throw new IllegalStateException(ISE);
    }
@@ -637,9 +578,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public void close() throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("close() " + this);
-      }
+      logger.trace("close() {}", this);
 
       if (closed) {
          return;
@@ -653,7 +592,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
             try {
                session.closeSession();
             } catch (Throwable t) {
-               ActiveMQRALogger.LOGGER.trace("Error closing session", t);
+               logger.trace("Error closing session", t);
             }
             i.remove();
          }
@@ -663,12 +602,10 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
          for (Iterator<TemporaryQueue> i = tempQueues.iterator(); i.hasNext(); ) {
             TemporaryQueue temp = i.next();
             try {
-               if (ActiveMQRASessionFactoryImpl.trace) {
-                  ActiveMQRALogger.LOGGER.trace("Closing temporary queue " + temp + " for " + this);
-               }
+               logger.trace("Closing temporary queue {} for {}", temp, this);
                temp.delete();
             } catch (Throwable t) {
-               ActiveMQRALogger.LOGGER.trace("Error deleting temporary queue", t);
+               logger.trace("Error deleting temporary queue", t);
             }
             i.remove();
          }
@@ -678,12 +615,10 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
          for (Iterator<TemporaryTopic> i = tempTopics.iterator(); i.hasNext(); ) {
             TemporaryTopic temp = i.next();
             try {
-               if (ActiveMQRASessionFactoryImpl.trace) {
-                  ActiveMQRALogger.LOGGER.trace("Closing temporary topic " + temp + " for " + this);
-               }
+               logger.trace("Closing temporary topic {} for {}", temp, this);
                temp.delete();
             } catch (Throwable t) {
-               ActiveMQRALogger.LOGGER.trace("Error deleting temporary queue", t);
+               logger.trace("Error deleting temporary queue", t);
             }
             i.remove();
          }
@@ -698,9 +633,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public void closeSession(final ActiveMQRASession session) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("closeSession(" + session + ")");
-      }
+      logger.trace("closeSession({})", session);
 
       synchronized (sessions) {
          sessions.remove(session);
@@ -714,9 +647,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public void addTemporaryQueue(final TemporaryQueue temp) {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("addTemporaryQueue(" + temp + ")");
-      }
+      logger.trace("addTemporaryQueue({})", temp);
 
       synchronized (tempQueues) {
          tempQueues.add(temp);
@@ -730,9 +661,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     */
    @Override
    public void addTemporaryTopic(final TemporaryTopic temp) {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("addTemporaryTopic(" + temp + ")");
-      }
+      logger.trace("addTemporaryTopic({})", temp);
 
       synchronized (tempTopics) {
          tempTopics.add(temp);
@@ -755,9 +684,9 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
                                                             String messageSelector,
                                                             ServerSessionPool sessionPool,
                                                             int maxMessages) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createSharedConnectionConsumer(" + topic + ", " + subscriptionName + ", " +
-                                          messageSelector + ", " + sessionPool + ", " + maxMessages + ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createSharedConnectionConsumer({}, {}, {}, {}, {})",
+            topic, subscriptionName, messageSelector, sessionPool, maxMessages);
       }
 
       throw new IllegalStateException(ISE);
@@ -769,9 +698,9 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
                                                                    String messageSelector,
                                                                    ServerSessionPool sessionPool,
                                                                    int maxMessages) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("createSharedDurableConnectionConsumer(" + topic + ", " + subscriptionName +
-                                          ", " + messageSelector + ", " + sessionPool + ", " + maxMessages + ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("createSharedDurableConnectionConsumer({}, {}, {}, {}, {})",
+            topic, subscriptionName, messageSelector, sessionPool, maxMessages);
       }
 
       throw new IllegalStateException(ISE);
@@ -800,13 +729,8 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
    protected ActiveMQRASession allocateConnection(boolean transacted,
                                                   int acknowledgeMode,
                                                   final int sessionType) throws JMSException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("allocateConnection(" + transacted +
-                                          ", " +
-                                          acknowledgeMode +
-                                          ", " +
-                                          sessionType +
-                                          ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("allocateConnection({}, {}, {})", transacted, acknowledgeMode, sessionType);
       }
 
       try {
@@ -817,36 +741,43 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
             //from createSession
             // In a Java EE web or EJB container, when there is an active JTA transaction in progress:
             //Both arguments {@code transacted} and {@code acknowledgeMode} are ignored.
-            if (inJtaTransaction()) {
+            // fix of ARTEMIS-1669 - when a JMSConnectionFactoryDefinition annotation with the transactional attribute set to false="false" is set
+            // then it should not be included in any JTA transaction and behave like that there is no JTA transaction.
+            if (!mcf.isIgnoreJTA() && (inJtaTransaction() || mcf.isInJtaTransaction())) {
                transacted = true;
                //from getAcknowledgeMode
-               // If the session is not transacted, returns the
-               // current acknowledgement mode for the session.
-               // If the session
-               // is transacted, returns SESSION_TRANSACTED.
+               // If the session is transacted, returns SESSION_TRANSACTED.
                acknowledgeMode = Session.SESSION_TRANSACTED;
             } else {
                //In the Java EE web or EJB container, when there is no active JTA transaction in progress
                // The argument {@code transacted} is ignored.
 
-               //The session will always be non-transacted,
-               transacted = false;
-               switch (acknowledgeMode) {
-                  //using one of the two acknowledgement modes AUTO_ACKNOWLEDGE and DUPS_OK_ACKNOWLEDGE.
-                  case Session.AUTO_ACKNOWLEDGE:
-                  case Session.DUPS_OK_ACKNOWLEDGE:
-                     //plus our own
-                  case ActiveMQJMSConstants.INDIVIDUAL_ACKNOWLEDGE:
-                  case ActiveMQJMSConstants.PRE_ACKNOWLEDGE:
-                     break;
-                  //The value {@code Session.CLIENT_ACKNOWLEDGE} may not be used.
-                  case Session.CLIENT_ACKNOWLEDGE:
-                     throw ActiveMQRABundle.BUNDLE.invalidClientAcknowledgeModeRuntime();
-                     //same with this although the spec doesn't explicitly say
-                  case Session.SESSION_TRANSACTED:
-                     throw ActiveMQRABundle.BUNDLE.invalidSessionTransactedModeRuntime();
-                  default:
-                     throw ActiveMQRABundle.BUNDLE.invalidAcknowledgeMode(acknowledgeMode);
+               //The session will always be non-transacted, unless allow-local-transactions is true
+               if (transacted && mcf.isAllowLocalTransactions()) {
+                  acknowledgeMode = Session.SESSION_TRANSACTED;
+               } else {
+                  transacted = false;
+                  switch (acknowledgeMode) {
+                     //using one of the two acknowledgement modes AUTO_ACKNOWLEDGE and DUPS_OK_ACKNOWLEDGE.
+                     case Session.AUTO_ACKNOWLEDGE:
+                     case Session.DUPS_OK_ACKNOWLEDGE:
+                        //plus our own
+                     case ActiveMQJMSConstants.INDIVIDUAL_ACKNOWLEDGE:
+                     case ActiveMQJMSConstants.PRE_ACKNOWLEDGE:
+                        break;
+                     //The value {@code Session.CLIENT_ACKNOWLEDGE} may not be used.
+                     case Session.CLIENT_ACKNOWLEDGE:
+                        throw ActiveMQRABundle.BUNDLE.invalidClientAcknowledgeModeRuntime();
+                        //same with this although the spec doesn't explicitly say
+                     case Session.SESSION_TRANSACTED:
+                        if (!mcf.isAllowLocalTransactions()) {
+                           throw ActiveMQRABundle.BUNDLE.invalidSessionTransactedModeRuntimeAllowLocal();
+                        }
+                        transacted = true;
+                        break;
+                     default:
+                        throw ActiveMQRABundle.BUNDLE.invalidAcknowledgeMode(acknowledgeMode);
+                  }
                }
             }
 
@@ -856,16 +787,12 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
             info.setClientID(clientID);
             info.setDefaults(((ActiveMQResourceAdapter) mcf.getResourceAdapter()).getProperties());
 
-            if (ActiveMQRASessionFactoryImpl.trace) {
-               ActiveMQRALogger.LOGGER.trace("Allocating session for " + this + " with request info=" + info);
-            }
+            logger.trace("Allocating session for {} with request info={}", this, info);
 
             ActiveMQRASession session = (ActiveMQRASession) cm.allocateConnection(mcf, info);
 
             try {
-               if (ActiveMQRASessionFactoryImpl.trace) {
-                  ActiveMQRALogger.LOGGER.trace("Allocated  " + this + " session=" + session);
-               }
+               logger.trace("Allocated  {} session={}", this, session);
 
                session.setActiveMQSessionFactory(this);
 
@@ -911,9 +838,7 @@ public final class ActiveMQRASessionFactoryImpl extends ActiveMQConnectionForCon
     * @throws IllegalStateException Thrown if closed
     */
    protected void checkClosed() throws IllegalStateException {
-      if (ActiveMQRASessionFactoryImpl.trace) {
-         ActiveMQRALogger.LOGGER.trace("checkClosed()" + this);
-      }
+      logger.trace("checkClosed() {}", this);
 
       if (closed) {
          throw new IllegalStateException("The connection is closed");
