@@ -70,6 +70,7 @@ import org.apache.activemq.artemis.core.server.plugin.ActiveMQServerPlugin;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.core.settings.impl.SlowConsumerPolicy;
 import org.apache.activemq.artemis.core.settings.impl.SlowConsumerThresholdMeasurementUnit;
+import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
 import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.utils.critical.CriticalAnalyzerPolicy;
 import org.junit.AfterClass;
@@ -402,83 +403,83 @@ public class FileConfigurationTest extends ConfigurationImplTest {
          }
       }
 
-      assertEquals(2, conf.getAddressesSettings().size());
+      assertEquals(2, conf.getAddressSettings().size());
 
-      assertTrue(conf.getAddressesSettings().get("a1") != null);
-      assertTrue(conf.getAddressesSettings().get("a2") != null);
+      assertTrue(conf.getAddressSettings().get("a1") != null);
+      assertTrue(conf.getAddressSettings().get("a2") != null);
 
-      assertEquals("a1.1", conf.getAddressesSettings().get("a1").getDeadLetterAddress().toString());
-      assertEquals(AddressSettings.DEFAULT_AUTO_CREATE_DEAD_LETTER_RESOURCES, conf.getAddressesSettings().get("a1").isAutoCreateDeadLetterResources());
-      assertEquals(AddressSettings.DEFAULT_DEAD_LETTER_QUEUE_PREFIX, conf.getAddressesSettings().get("a1").getDeadLetterQueuePrefix());
-      assertEquals(AddressSettings.DEFAULT_DEAD_LETTER_QUEUE_SUFFIX, conf.getAddressesSettings().get("a1").getDeadLetterQueueSuffix());
-      assertEquals("a1.2", conf.getAddressesSettings().get("a1").getExpiryAddress().toString());
-      assertEquals(1L, (long) conf.getAddressesSettings().get("a1").getExpiryDelay());
-      assertEquals(2L, (long) conf.getAddressesSettings().get("a1").getMinExpiryDelay());
-      assertEquals(3L, (long) conf.getAddressesSettings().get("a1").getMaxExpiryDelay());
-      assertEquals(AddressSettings.DEFAULT_AUTO_CREATE_EXPIRY_RESOURCES, conf.getAddressesSettings().get("a1").isAutoCreateExpiryResources());
-      assertEquals(AddressSettings.DEFAULT_EXPIRY_QUEUE_PREFIX, conf.getAddressesSettings().get("a1").getExpiryQueuePrefix());
-      assertEquals(AddressSettings.DEFAULT_EXPIRY_QUEUE_SUFFIX, conf.getAddressesSettings().get("a1").getExpiryQueueSuffix());
-      assertEquals(1, conf.getAddressesSettings().get("a1").getRedeliveryDelay());
-      assertEquals(0.5, conf.getAddressesSettings().get("a1").getRedeliveryCollisionAvoidanceFactor(), 0);
-      assertEquals(856686592L, conf.getAddressesSettings().get("a1").getMaxSizeBytes());
-      assertEquals(817381738L, conf.getAddressesSettings().get("a1").getPageSizeBytes());
-      assertEquals(10, conf.getAddressesSettings().get("a1").getPageCacheMaxSize());
-      assertEquals(4, conf.getAddressesSettings().get("a1").getMessageCounterHistoryDayLimit());
-      assertEquals(10, conf.getAddressesSettings().get("a1").getSlowConsumerThreshold());
-      assertEquals(SlowConsumerThresholdMeasurementUnit.MESSAGES_PER_HOUR, conf.getAddressesSettings().get("a1").getSlowConsumerThresholdMeasurementUnit());
-      assertEquals(5, conf.getAddressesSettings().get("a1").getSlowConsumerCheckPeriod());
-      assertEquals(SlowConsumerPolicy.NOTIFY, conf.getAddressesSettings().get("a1").getSlowConsumerPolicy());
-      assertEquals(true, conf.getAddressesSettings().get("a1").isAutoCreateJmsQueues());
-      assertEquals(true, conf.getAddressesSettings().get("a1").isAutoDeleteJmsQueues());
-      assertEquals(true, conf.getAddressesSettings().get("a1").isAutoCreateJmsTopics());
-      assertEquals(true, conf.getAddressesSettings().get("a1").isAutoDeleteJmsTopics());
-      assertEquals(0, conf.getAddressesSettings().get("a1").getAutoDeleteQueuesDelay());
-      assertEquals(0, conf.getAddressesSettings().get("a1").getAutoDeleteAddressesDelay());
-      assertEquals(false, conf.getAddressesSettings().get("a1").isDefaultPurgeOnNoConsumers());
-      assertEquals(5, conf.getAddressesSettings().get("a1").getDefaultMaxConsumers());
-      assertEquals(RoutingType.ANYCAST, conf.getAddressesSettings().get("a1").getDefaultQueueRoutingType());
-      assertEquals(RoutingType.MULTICAST, conf.getAddressesSettings().get("a1").getDefaultAddressRoutingType());
-      assertEquals(3, conf.getAddressesSettings().get("a1").getDefaultRingSize());
-      assertEquals(0, conf.getAddressesSettings().get("a1").getRetroactiveMessageCount());
-      assertTrue(conf.getAddressesSettings().get("a1").isEnableMetrics());
-      assertTrue(conf.getAddressesSettings().get("a1").isEnableIngressTimestamp());
+      assertEquals("a1.1", conf.getAddressSettings().get("a1").getDeadLetterAddress().toString());
+      assertEquals(AddressSettings.DEFAULT_AUTO_CREATE_DEAD_LETTER_RESOURCES, conf.getAddressSettings().get("a1").isAutoCreateDeadLetterResources());
+      assertEquals(AddressSettings.DEFAULT_DEAD_LETTER_QUEUE_PREFIX, conf.getAddressSettings().get("a1").getDeadLetterQueuePrefix());
+      assertEquals(AddressSettings.DEFAULT_DEAD_LETTER_QUEUE_SUFFIX, conf.getAddressSettings().get("a1").getDeadLetterQueueSuffix());
+      assertEquals("a1.2", conf.getAddressSettings().get("a1").getExpiryAddress().toString());
+      assertEquals(1L, (long) conf.getAddressSettings().get("a1").getExpiryDelay());
+      assertEquals(2L, (long) conf.getAddressSettings().get("a1").getMinExpiryDelay());
+      assertEquals(3L, (long) conf.getAddressSettings().get("a1").getMaxExpiryDelay());
+      assertEquals(AddressSettings.DEFAULT_AUTO_CREATE_EXPIRY_RESOURCES, conf.getAddressSettings().get("a1").isAutoCreateExpiryResources());
+      assertEquals(AddressSettings.DEFAULT_EXPIRY_QUEUE_PREFIX, conf.getAddressSettings().get("a1").getExpiryQueuePrefix());
+      assertEquals(AddressSettings.DEFAULT_EXPIRY_QUEUE_SUFFIX, conf.getAddressSettings().get("a1").getExpiryQueueSuffix());
+      assertEquals(1, conf.getAddressSettings().get("a1").getRedeliveryDelay());
+      assertEquals(0.5, conf.getAddressSettings().get("a1").getRedeliveryCollisionAvoidanceFactor(), 0);
+      assertEquals(856686592L, conf.getAddressSettings().get("a1").getMaxSizeBytes());
+      assertEquals(817381738L, conf.getAddressSettings().get("a1").getPageSizeBytes());
+      assertEquals(10, conf.getAddressSettings().get("a1").getPageCacheMaxSize());
+      assertEquals(4, conf.getAddressSettings().get("a1").getMessageCounterHistoryDayLimit());
+      assertEquals(10, conf.getAddressSettings().get("a1").getSlowConsumerThreshold());
+      assertEquals(SlowConsumerThresholdMeasurementUnit.MESSAGES_PER_HOUR, conf.getAddressSettings().get("a1").getSlowConsumerThresholdMeasurementUnit());
+      assertEquals(5, conf.getAddressSettings().get("a1").getSlowConsumerCheckPeriod());
+      assertEquals(SlowConsumerPolicy.NOTIFY, conf.getAddressSettings().get("a1").getSlowConsumerPolicy());
+      assertEquals(true, conf.getAddressSettings().get("a1").isAutoCreateJmsQueues());
+      assertEquals(true, conf.getAddressSettings().get("a1").isAutoDeleteJmsQueues());
+      assertEquals(true, conf.getAddressSettings().get("a1").isAutoCreateJmsTopics());
+      assertEquals(true, conf.getAddressSettings().get("a1").isAutoDeleteJmsTopics());
+      assertEquals(0, conf.getAddressSettings().get("a1").getAutoDeleteQueuesDelay());
+      assertEquals(0, conf.getAddressSettings().get("a1").getAutoDeleteAddressesDelay());
+      assertEquals(false, conf.getAddressSettings().get("a1").isDefaultPurgeOnNoConsumers());
+      assertEquals(5, conf.getAddressSettings().get("a1").getDefaultMaxConsumers());
+      assertEquals(RoutingType.ANYCAST, conf.getAddressSettings().get("a1").getDefaultQueueRoutingType());
+      assertEquals(RoutingType.MULTICAST, conf.getAddressSettings().get("a1").getDefaultAddressRoutingType());
+      assertEquals(3, conf.getAddressSettings().get("a1").getDefaultRingSize());
+      assertEquals(0, conf.getAddressSettings().get("a1").getRetroactiveMessageCount());
+      assertTrue(conf.getAddressSettings().get("a1").isEnableMetrics());
+      assertTrue(conf.getAddressSettings().get("a1").isEnableIngressTimestamp());
 
-      assertEquals("a2.1", conf.getAddressesSettings().get("a2").getDeadLetterAddress().toString());
-      assertEquals(true, conf.getAddressesSettings().get("a2").isAutoCreateDeadLetterResources());
-      assertEquals("", conf.getAddressesSettings().get("a2").getDeadLetterQueuePrefix().toString());
-      assertEquals(".DLQ", conf.getAddressesSettings().get("a2").getDeadLetterQueueSuffix().toString());
-      assertEquals("a2.2", conf.getAddressesSettings().get("a2").getExpiryAddress().toString());
-      assertEquals(-1L, (long) conf.getAddressesSettings().get("a2").getExpiryDelay());
-      assertEquals(-1L, (long) conf.getAddressesSettings().get("a2").getMinExpiryDelay());
-      assertEquals(-1L, (long) conf.getAddressesSettings().get("a2").getMaxExpiryDelay());
-      assertEquals(true, conf.getAddressesSettings().get("a2").isAutoCreateDeadLetterResources());
-      assertEquals("", conf.getAddressesSettings().get("a2").getExpiryQueuePrefix().toString());
-      assertEquals(".EXP", conf.getAddressesSettings().get("a2").getExpiryQueueSuffix().toString());
-      assertEquals(5, conf.getAddressesSettings().get("a2").getRedeliveryDelay());
-      assertEquals(0.0, conf.getAddressesSettings().get("a2").getRedeliveryCollisionAvoidanceFactor(), 0);
-      assertEquals(932489234928324L, conf.getAddressesSettings().get("a2").getMaxSizeBytes());
-      assertEquals(712671626L, conf.getAddressesSettings().get("a2").getPageSizeBytes());
-      assertEquals(20, conf.getAddressesSettings().get("a2").getPageCacheMaxSize());
-      assertEquals(8, conf.getAddressesSettings().get("a2").getMessageCounterHistoryDayLimit());
-      assertEquals(20, conf.getAddressesSettings().get("a2").getSlowConsumerThreshold());
-      assertEquals(SlowConsumerThresholdMeasurementUnit.MESSAGES_PER_DAY, conf.getAddressesSettings().get("a2").getSlowConsumerThresholdMeasurementUnit());
-      assertEquals(15, conf.getAddressesSettings().get("a2").getSlowConsumerCheckPeriod());
-      assertEquals(SlowConsumerPolicy.KILL, conf.getAddressesSettings().get("a2").getSlowConsumerPolicy());
-      assertEquals(false, conf.getAddressesSettings().get("a2").isAutoCreateJmsQueues());
-      assertEquals(false, conf.getAddressesSettings().get("a2").isAutoDeleteJmsQueues());
-      assertEquals(false, conf.getAddressesSettings().get("a2").isAutoCreateJmsTopics());
-      assertEquals(false, conf.getAddressesSettings().get("a2").isAutoDeleteJmsTopics());
-      assertEquals(500, conf.getAddressesSettings().get("a2").getAutoDeleteQueuesDelay());
-      assertEquals(1000, conf.getAddressesSettings().get("a2").getAutoDeleteAddressesDelay());
-      assertEquals(true, conf.getAddressesSettings().get("a2").isDefaultPurgeOnNoConsumers());
-      assertEquals(15, conf.getAddressesSettings().get("a2").getDefaultMaxConsumers());
-      assertEquals(RoutingType.MULTICAST, conf.getAddressesSettings().get("a2").getDefaultQueueRoutingType());
-      assertEquals(RoutingType.ANYCAST, conf.getAddressesSettings().get("a2").getDefaultAddressRoutingType());
-      assertEquals(10000, conf.getAddressesSettings().get("a2").getDefaultConsumerWindowSize());
-      assertEquals(-1, conf.getAddressesSettings().get("a2").getDefaultRingSize());
-      assertEquals(10, conf.getAddressesSettings().get("a2").getRetroactiveMessageCount());
-      assertFalse(conf.getAddressesSettings().get("a2").isEnableMetrics());
-      assertFalse(conf.getAddressesSettings().get("a2").isEnableIngressTimestamp());
+      assertEquals("a2.1", conf.getAddressSettings().get("a2").getDeadLetterAddress().toString());
+      assertEquals(true, conf.getAddressSettings().get("a2").isAutoCreateDeadLetterResources());
+      assertEquals("", conf.getAddressSettings().get("a2").getDeadLetterQueuePrefix().toString());
+      assertEquals(".DLQ", conf.getAddressSettings().get("a2").getDeadLetterQueueSuffix().toString());
+      assertEquals("a2.2", conf.getAddressSettings().get("a2").getExpiryAddress().toString());
+      assertEquals(-1L, (long) conf.getAddressSettings().get("a2").getExpiryDelay());
+      assertEquals(-1L, (long) conf.getAddressSettings().get("a2").getMinExpiryDelay());
+      assertEquals(-1L, (long) conf.getAddressSettings().get("a2").getMaxExpiryDelay());
+      assertEquals(true, conf.getAddressSettings().get("a2").isAutoCreateDeadLetterResources());
+      assertEquals("", conf.getAddressSettings().get("a2").getExpiryQueuePrefix().toString());
+      assertEquals(".EXP", conf.getAddressSettings().get("a2").getExpiryQueueSuffix().toString());
+      assertEquals(5, conf.getAddressSettings().get("a2").getRedeliveryDelay());
+      assertEquals(0.0, conf.getAddressSettings().get("a2").getRedeliveryCollisionAvoidanceFactor(), 0);
+      assertEquals(932489234928324L, conf.getAddressSettings().get("a2").getMaxSizeBytes());
+      assertEquals(712671626L, conf.getAddressSettings().get("a2").getPageSizeBytes());
+      assertEquals(20, conf.getAddressSettings().get("a2").getPageCacheMaxSize());
+      assertEquals(8, conf.getAddressSettings().get("a2").getMessageCounterHistoryDayLimit());
+      assertEquals(20, conf.getAddressSettings().get("a2").getSlowConsumerThreshold());
+      assertEquals(SlowConsumerThresholdMeasurementUnit.MESSAGES_PER_DAY, conf.getAddressSettings().get("a2").getSlowConsumerThresholdMeasurementUnit());
+      assertEquals(15, conf.getAddressSettings().get("a2").getSlowConsumerCheckPeriod());
+      assertEquals(SlowConsumerPolicy.KILL, conf.getAddressSettings().get("a2").getSlowConsumerPolicy());
+      assertEquals(false, conf.getAddressSettings().get("a2").isAutoCreateJmsQueues());
+      assertEquals(false, conf.getAddressSettings().get("a2").isAutoDeleteJmsQueues());
+      assertEquals(false, conf.getAddressSettings().get("a2").isAutoCreateJmsTopics());
+      assertEquals(false, conf.getAddressSettings().get("a2").isAutoDeleteJmsTopics());
+      assertEquals(500, conf.getAddressSettings().get("a2").getAutoDeleteQueuesDelay());
+      assertEquals(1000, conf.getAddressSettings().get("a2").getAutoDeleteAddressesDelay());
+      assertEquals(true, conf.getAddressSettings().get("a2").isDefaultPurgeOnNoConsumers());
+      assertEquals(15, conf.getAddressSettings().get("a2").getDefaultMaxConsumers());
+      assertEquals(RoutingType.MULTICAST, conf.getAddressSettings().get("a2").getDefaultQueueRoutingType());
+      assertEquals(RoutingType.ANYCAST, conf.getAddressSettings().get("a2").getDefaultAddressRoutingType());
+      assertEquals(10000, conf.getAddressSettings().get("a2").getDefaultConsumerWindowSize());
+      assertEquals(-1, conf.getAddressSettings().get("a2").getDefaultRingSize());
+      assertEquals(10, conf.getAddressSettings().get("a2").getRetroactiveMessageCount());
+      assertFalse(conf.getAddressSettings().get("a2").isEnableMetrics());
+      assertFalse(conf.getAddressSettings().get("a2").isEnableIngressTimestamp());
 
       assertTrue(conf.getResourceLimitSettings().containsKey("myUser"));
       assertEquals(104, conf.getResourceLimitSettings().get("myUser").getMaxConnections());
@@ -933,4 +934,23 @@ public class FileConfigurationTest extends ConfigurationImplTest {
          return null;
       }
    }
+
+
+   @Test
+   public void testValidateCache() throws Exception {
+
+      AssertionLoggerHandler.startCapture(true);
+      try {
+         FileConfiguration fc = new FileConfiguration();
+         FileDeploymentManager deploymentManager = new FileDeploymentManager(getConfigurationName());
+         deploymentManager.addDeployable(fc);
+         deploymentManager.readConfiguration();
+         Assert.assertTrue(AssertionLoggerHandler.findText("AMQ224117"));
+         Assert.assertEquals(1, AssertionLoggerHandler.countText("AMQ224117"));
+      } finally {
+         AssertionLoggerHandler.stopCapture();
+      }
+
+   }
+
 }
