@@ -92,15 +92,17 @@ import org.apache.activemq.artemis.core.server.impl.InVMNodeManager;
 import org.apache.activemq.artemis.quorum.file.FileBasedPrimitiveManager;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.utils.PortCheckRule;
-import org.jboss.logging.Logger;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.ClassRule;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 public abstract class ClusterTestBase extends ActiveMQTestBase {
 
-   private static final Logger log = Logger.getLogger(ClusterTestBase.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    private static final int[] PORTS = {TransportConstants.DEFAULT_PORT, TransportConstants.DEFAULT_PORT + 1, TransportConstants.DEFAULT_PORT + 2, TransportConstants.DEFAULT_PORT + 3, TransportConstants.DEFAULT_PORT + 4, TransportConstants.DEFAULT_PORT + 5, TransportConstants.DEFAULT_PORT + 6, TransportConstants.DEFAULT_PORT + 7, TransportConstants.DEFAULT_PORT + 8, TransportConstants.DEFAULT_PORT + 9,};
 
@@ -148,7 +150,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
       try {
          pluggableQuorumConfiguration = new DistributedPrimitiveManagerConfiguration(FileBasedPrimitiveManager.class.getName(), Collections.singletonMap("locks-folder", temporaryFolder.newFolder("manager").toString()));
       } catch (IOException ioException) {
-         log.error(ioException);
+         logger.error(ioException.getMessage(), ioException);
          return null;
       }
       return pluggableQuorumConfiguration;
@@ -279,7 +281,9 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
    protected void waitForFailoverTopology(final int bNode, final int... nodes) throws Exception {
       ActiveMQServer server = servers[bNode];
 
-      log.debug("waiting for " + Arrays.toString(nodes) + " on the topology for server = " + server);
+      if (logger.isDebugEnabled()) {
+         logger.debug("waiting for {} on the topology for server = {}",  Arrays.toString(nodes), server);
+      }
 
       long start = System.currentTimeMillis();
 
@@ -323,7 +327,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
                topology +
                ")";
 
-            log.error(msg);
+            logger.error(msg);
 
             logTopologyDiagram();
 
@@ -333,6 +337,10 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
    }
 
    private void logTopologyDiagram() {
+      if (!logger.isDebugEnabled()) {
+         return;
+      }
+
       try {
          StringBuffer topologyDiagram = new StringBuffer();
          for (ActiveMQServer activeMQServer : servers) {
@@ -379,9 +387,9 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
             }
          }
          topologyDiagram.append("\n");
-         log.debug(topologyDiagram.toString());
+         logger.debug(topologyDiagram.toString());
       } catch (Throwable e) {
-         log.warn("error printing the topology::" + e.getMessage(), e);
+         logger.warn(String.format("error printing the topology::%s", e.getMessage()), e);
       }
    }
 
@@ -424,7 +432,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
       if (!servers[node].waitForActivation(waitTimeout, TimeUnit.MILLISECONDS)) {
          String msg = "Timed out waiting for server starting = " + node;
 
-         log.error(msg);
+         logger.error(msg);
 
          throw new IllegalStateException(msg);
       }
@@ -435,15 +443,10 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
                                   final int expectedBindingCount,
                                   final int expectedConsumerCount,
                                   final boolean local) throws Exception {
-      log.debug("waiting for bindings on node " + node +
-                   " address " +
-                   address +
-                   " expectedBindingCount " +
-                   expectedBindingCount +
-                   " consumerCount " +
-                   expectedConsumerCount +
-                   " local " +
-                   local);
+      if (logger.isDebugEnabled()) {
+         logger.debug("waiting for bindings on node {} address {} expectedBindingCount {} consumerCount {} local {}",
+                   node, address, expectedBindingCount, expectedConsumerCount, local);
+      }
 
       ActiveMQServer server = servers[node];
 
@@ -460,14 +463,14 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
       PostOffice po = server.getPostOffice();
       Bindings bindings = po.getBindingsForAddress(new SimpleString(address));
 
-      log.debug("=======================================================================");
-      log.debug("Binding information for address = " + address + " on node " + node);
+      logger.debug("=======================================================================");
+      logger.debug("Binding information for address = {} on node {}", address, node);
 
       for (Binding binding : bindings.getBindings()) {
          if (binding.isConnected() && (binding instanceof LocalQueueBinding && local || binding instanceof RemoteQueueBinding && !local)) {
             QueueBinding qBinding = (QueueBinding) binding;
 
-            log.debug("Binding = " + qBinding + ", queue=" + qBinding.getQueue());
+            logger.debug("Binding = {}, queue={}", qBinding, qBinding.getQueue());
          }
       }
 
@@ -574,7 +577,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
          filterString = ClusterTestBase.FILTER_PROP.toString() + "='" + filterVal + "'";
       }
 
-      log.debug("Creating " + queueName + " , address " + address + " on " + servers[node]);
+      logger.debug("Creating {} , address {} on {}", queueName, address, servers[node]);
 
       session.createQueue(new QueueConfiguration(queueName).setAddress(address).setRoutingType(routingType).setFilterString(filterString).setDurable(durable));
 
@@ -723,7 +726,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
                               final int msgEnd,
                               final boolean durable,
                               final String filterVal) throws Exception {
-      sendInRange(node, address, msgStart, msgEnd, durable, filterVal, null);
+      sendInRange(node, address, msgStart, msgEnd, durable, filterVal, null, null);
    }
 
    protected void sendInRange(final int node,
@@ -732,6 +735,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
                               final int msgEnd,
                               final boolean durable,
                               final String filterVal,
+                              final RoutingType routingType,
                               final AtomicInteger duplicateDetectionSeq) throws Exception {
       ClientSessionFactory sf = sfs[node];
 
@@ -756,6 +760,10 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
                message.putStringProperty(Message.HDR_DUPLICATE_DETECTION_ID, new SimpleString(str));
             }
 
+            if (routingType != null) {
+               message.setRoutingType(routingType);
+            }
+
             message.putIntProperty(ClusterTestBase.COUNT_PROP, i);
 
             if (isLargeMessage()) {
@@ -853,7 +861,17 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
                        final boolean durable,
                        final String filterVal,
                        final AtomicInteger duplicateDetectionCounter) throws Exception {
-      sendInRange(node, address, 0, numMessages, durable, filterVal, duplicateDetectionCounter);
+      send(node, address, numMessages, durable, filterVal, null, duplicateDetectionCounter);
+   }
+
+   protected void send(final int node,
+                       final String address,
+                       final int numMessages,
+                       final boolean durable,
+                       final String filterVal,
+                       final RoutingType routingType,
+                       final AtomicInteger duplicateDetectionCounter) throws Exception {
+      sendInRange(node, address, 0, numMessages, durable, filterVal, routingType, duplicateDetectionCounter);
    }
 
    protected void verifyReceiveAllInRange(final boolean ack,
@@ -898,7 +916,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
             ClientMessage message = holder.consumer.receive(2000);
 
             if (message == null) {
-               log.debug("*** dumping consumers:");
+               logger.debug("*** dumping consumers:");
 
                dumpConsumers();
 
@@ -982,7 +1000,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
             ClientMessage message = holder.consumer.receive(WAIT_TIMEOUT);
 
             if (message == null) {
-               log.debug("*** dumping consumers:");
+               logger.debug("*** dumping consumers:");
 
                dumpConsumers();
 
@@ -1008,11 +1026,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
                      message.getObjectProperty(ClusterTestBase.COUNT_PROP);
                }
                outOfOrder = true;
-               log.debug("Message j=" + j + " was received out of order = " +
-                                     message.getObjectProperty(ClusterTestBase.COUNT_PROP));
-               log.debug("Message j=" + j +
-                           " was received out of order = " +
-                           message.getObjectProperty(ClusterTestBase.COUNT_PROP));
+               logger.debug("Message j={} was received out of order = {}", j, message.getObjectProperty(ClusterTestBase.COUNT_PROP));
             }
          }
       }
@@ -1023,7 +1037,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
    private void dumpConsumers() throws Exception {
       for (int i = 0; i < consumers.length; i++) {
          if (consumers[i] != null && !consumers[i].consumer.isClosed()) {
-            log.debug("Dumping consumer " + i);
+            logger.debug("Dumping consumer {}", i);
 
             checkReceive(i);
          }
@@ -1076,11 +1090,9 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
             message = holder.consumer.receive(500);
 
             if (message != null) {
-               log.debug("check receive Consumer " + consumerID +
-                           " received message " +
-                           message.getObjectProperty(ClusterTestBase.COUNT_PROP));
+               logger.debug("check receive Consumer {} received message {}", consumerID, message.getObjectProperty(ClusterTestBase.COUNT_PROP));
             } else {
-               log.debug("check receive Consumer " + consumerID + " null message");
+               logger.debug("check receive Consumer {} null message", consumerID);
             }
          }
          while (message != null);
@@ -1250,7 +1262,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
 
                checkMessageBody(message);
 
-               // log.debug("consumer " + consumerIDs[i] + " received message " + count);
+               // logger.debug("consumer {} received message {}", consumerIDs[i], count);
 
                Assert.assertFalse(counts.contains(count));
 
@@ -1980,7 +1992,7 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
 
    protected void startServers(final int... nodes) throws Exception {
       for (int node : nodes) {
-         log.debug("#test start node " + node);
+         logger.debug("#test start node {}", node);
          final long currentTime = System.currentTimeMillis();
          boolean waitForSelf = currentTime - timeStarts[node] < TIMEOUT_START_SERVER;
          boolean waitForPrevious = node > 0 && currentTime - timeStarts[node - 1] < TIMEOUT_START_SERVER;
@@ -1988,10 +2000,10 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
             Thread.sleep(TIMEOUT_START_SERVER);
          }
          timeStarts[node] = System.currentTimeMillis();
-         log.debug("starting server " + servers[node]);
+         logger.debug("starting server {}", servers[node]);
          servers[node].start();
 
-         log.debug("started server " + servers[node]);
+         logger.debug("started server {}", servers[node]);
          waitForServerToStart(servers[node]);
 
          if (servers[node].getStorageManager() != null && isForceUniqueStorageManagerIds()) {
@@ -2016,7 +2028,10 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
    }
 
    protected void stopServers(final int... nodes) throws Exception {
-      log.debug("Stopping nodes " + Arrays.toString(nodes));
+      if (logger.isDebugEnabled()) {
+         logger.debug("Stopping nodes {}", Arrays.toString(nodes));
+      }
+
       Exception exception = null;
       for (int node : nodes) {
          if (servers[node] != null && servers[node].isStarted()) {
@@ -2028,9 +2043,9 @@ public abstract class ClusterTestBase extends ActiveMQTestBase {
 
                timeStarts[node] = System.currentTimeMillis();
 
-               log.debug("stopping server " + node);
+               logger.debug("stopping server {}", node);
                servers[node].stop();
-               log.debug("server " + node + " stopped");
+               logger.debug("server {} stopped", node);
             } catch (Exception e) {
                exception = e;
             }
