@@ -44,7 +44,6 @@ import org.apache.activemq.artemis.core.postoffice.impl.LocalQueueBinding;
 import org.apache.activemq.artemis.core.protocol.mqtt.MQTTInterceptor;
 import org.apache.activemq.artemis.core.protocol.mqtt.MQTTProtocolManager;
 import org.apache.activemq.artemis.core.protocol.mqtt.MQTTSessionState;
-import org.apache.activemq.artemis.core.protocol.mqtt.MQTTUtil;
 import org.apache.activemq.artemis.core.remoting.impl.AbstractAcceptor;
 import org.apache.activemq.artemis.core.remoting.impl.netty.TransportConstants;
 import org.apache.activemq.artemis.core.security.Role;
@@ -68,13 +67,15 @@ import org.eclipse.paho.mqttv5.client.MqttDisconnectResponse;
 import org.eclipse.paho.mqttv5.client.persist.MemoryPersistence;
 import org.eclipse.paho.mqttv5.common.MqttException;
 import org.eclipse.paho.mqttv5.common.packet.MqttProperties;
-import org.jboss.logging.Logger;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.rules.TestName;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 import static java.util.Collections.singletonList;
 import static org.apache.activemq.artemis.core.protocol.mqtt.MQTTProtocolManagerFactory.MQTT_PROTOCOL_NAME;
@@ -110,7 +111,7 @@ public class MQTT5TestSupport extends ActiveMQTestBase {
       return new MqttAsyncClient(protocol + "://localhost:" + (isUseSsl() ? getSslPort() : getPort()), clientId, new MemoryPersistence());
    }
 
-   private static final Logger log = Logger.getLogger(MQTT5TestSupport.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
    protected static final long DEFAULT_TIMEOUT = 300000;
    protected ActiveMQServer server;
 
@@ -166,7 +167,6 @@ public class MQTT5TestSupport extends ActiveMQTestBase {
       exceptions.clear();
       startBroker();
       createJMSConnection();
-      org.jboss.logmanager.Logger.getLogger(MQTTUtil.class.getName()).setLevel(org.jboss.logmanager.Level.TRACE);
    }
 
    @Override
@@ -239,7 +239,7 @@ public class MQTT5TestSupport extends ActiveMQTestBase {
       AddressSettings addressSettings = new AddressSettings();
       addressSettings.setDeadLetterAddress(DEAD_LETTER_ADDRESS);
       addressSettings.setExpiryAddress(EXPIRY_ADDRESS);
-      defaultConfig.getAddressesSettings().put("#", addressSettings);
+      defaultConfig.getAddressSettings().put("#", addressSettings);
       defaultConfig.setMqttSessionScanInterval(200);
       return createServer(true, defaultConfig);
    }
@@ -255,7 +255,7 @@ public class MQTT5TestSupport extends ActiveMQTestBase {
       TransportConfiguration transportConfiguration = new TransportConfiguration(NETTY_ACCEPTOR_FACTORY, params);
       server.getConfiguration().getAcceptorConfigurations().add(transportConfiguration);
 
-      log.debug("Added CORE connector to broker");
+      logger.debug("Added CORE connector to broker");
    }
 
    protected void addMQTTConnector() throws Exception {
@@ -266,7 +266,7 @@ public class MQTT5TestSupport extends ActiveMQTestBase {
       server.getConfiguration().addAcceptorConfiguration(MQTT_PROTOCOL_NAME, "tcp://localhost:" + (isUseSsl() ? sslPort : port) + "?protocols=MQTT;anycastPrefix=anycast:;multicastPrefix=multicast:" + (isUseSsl() ? "&sslEnabled=true&keyStorePath=server-keystore.p12&keyStorePassword=securepass" : "") + (isMutualSsl() ? "&needClientAuth=true&trustStorePath=client-ca-truststore.p12&trustStorePassword=securepass" : ""));
       server.getConfiguration().setConnectionTtlCheckInterval(100);
 
-      log.debug("Added MQTT connector to broker");
+      logger.debug("Added MQTT connector to broker");
    }
 
    public void stopBroker() throws Exception {
@@ -314,15 +314,27 @@ public class MQTT5TestSupport extends ActiveMQTestBase {
    }
 
    public Map<String, MQTTSessionState> getSessionStates() {
-      Acceptor acceptor = server.getRemotingService().getAcceptor("MQTT");
-      if (acceptor instanceof AbstractAcceptor) {
-         ProtocolManager protocolManager = ((AbstractAcceptor) acceptor).getProtocolMap().get("MQTT");
-         if (protocolManager instanceof MQTTProtocolManager) {
-            return ((MQTTProtocolManager) protocolManager).getSessionStates();
-         }
-
+      MQTTProtocolManager protocolManager = getProtocolManager();
+      if (protocolManager == null) {
+         return Collections.emptyMap();
+      } else {
+         return protocolManager.getSessionStates();
       }
-      return Collections.emptyMap();
+   }
+
+   public void scanSessions() {
+      getProtocolManager().scanSessions();
+   }
+
+   public MQTTProtocolManager getProtocolManager() {
+      Acceptor acceptor = server.getRemotingService().getAcceptor(MQTT_PROTOCOL_NAME);
+      if (acceptor instanceof AbstractAcceptor) {
+         ProtocolManager protocolManager = ((AbstractAcceptor) acceptor).getProtocolMap().get(MQTT_PROTOCOL_NAME);
+         if (protocolManager instanceof MQTTProtocolManager) {
+            return (MQTTProtocolManager) protocolManager;
+         }
+      }
+      return null;
    }
 
    protected Queue getSubscriptionQueue(String TOPIC) {
